@@ -450,6 +450,9 @@ mixed <- function(formula,
     #browser()
     resetted <- NULL
     for (i in vars.to.check) {
+      if (is.character(data[,i])) {
+        data[,i] <- factor(data[,i])
+      }
       if (is.factor(data[,i])) {
         if (is.null(attr(data[,i], "contrasts")) & 
             (options("contrasts")[[1]][1] != "contr.sum")) {
@@ -965,11 +968,12 @@ expand_re_fun <- function(all.terms, data) {
       if (colnames(tmp_model.matrix[[i]])[1] == "(Intercept)") {
         tmp_model.matrix[[i]] <- tmp_model.matrix[[i]][,-1, drop = FALSE]
         re_contains_intercept[i] <- TRUE
-      }
+      } 
       if (ncol(tmp_model.matrix[[i]]) > 0) {
         colnames(tmp_model.matrix[[i]]) <- 
           paste0("re", i, ".", 
                 gsub(":", "_by_", colnames(tmp_model.matrix[[i]])))
+        colnames(tmp_model.matrix[[i]]) <- make.names(colnames(tmp_model.matrix[[i]]))
         new_random[i] <- 
           paste0("(", as.numeric(re_contains_intercept[i]), "+", 
                 paste0(colnames(tmp_model.matrix[[i]]), collapse = "+"), 
